@@ -17,16 +17,16 @@ def configs(request):
 
 @pytest.fixture(scope="class", params=CONFIGS, ids=[f.name for f in CONFIGS])
 def config(request):
-    return CiscoConfParse(request.param, syntax="ios")
+    return CiscoConfParse(request.param, syntax="ios", ignore_blank_lines=False)
 
 
 @pytest.fixture(scope="class")
 def current(configs):
     return (
-        CiscoConfParse(configs.current.split("\n"), syntax="ios") if configs else None
+        CiscoConfParse(configs.current.split("\n"), syntax="ios", ignore_blank_lines=False) if configs else None
     )
 
 
 @pytest.fixture(scope="class")
 def start(configs):
-    return CiscoConfParse(configs.start.split("\n"), syntax="ios") if configs else None
+    return CiscoConfParse(configs.start.split("\n"), syntax="ios", ignore_blank_lines=False) if configs else None
